##  Customizing Table Columns in the Transformations Explorer
By default, the table displays key details like initiative, name, completion date, and status. You can add or remove additional attributes as columns. To do so:
  1. Choose the eye icon at the top right of the table to open the column selection panel.
  2. To add columns, choose the plus icon next to any attribute in the Inactive Columns section. Use the search bar to find specific columns quickly.
  3. To remove or reorder columns, drag items in the Active Columns section to reorder them or choose the “x” icon to remove a column.
![Adding Columns in the Transformations Explorer Table](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loiof9e8767bbd7d4b598316729437b4cf8f_LowRes.png)
Adding Columns in the Transformations Explorer Table
